# Table of Contents

- [managing-fact-sheet-tags-dynamically-based-on-relation-changes](<./managing-fact-sheet-tags-dynamically-based-on-relation-changes.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Managing Fact Sheet Tags Dynamically Based on Relation Changes](<./Managing-Fact-Sheet-Tags-Dynamically-Based-on-Relation-Changes.md>)
  - [Overview](<./Managing-Fact-Sheet-Tags-Dynamically-Based-on-Relation-Changes/Overview.md>)
  - [Prerequisites](<./Managing-Fact-Sheet-Tags-Dynamically-Based-on-Relation-Changes/Prerequisites.md>)
  - [Step 1: Create Tag Groups](<./Managing-Fact-Sheet-Tags-Dynamically-Based-on-Relation-Changes/Step-1-Create-Tag-Groups.md>)
  - [Step 2: Create a Webhook for Fact Sheet Relations](<./Managing-Fact-Sheet-Tags-Dynamically-Based-on-Relation-Changes/Step-2-Create-a-Webhook-for-Fact-Sheet-Relations.md>)
  - [Step 3: Create and Deploy a Function](<./Managing-Fact-Sheet-Tags-Dynamically-Based-on-Relation-Changes/Step-3-Create-and-Deploy-a-Function.md>)
  - [Summary](<./Managing-Fact-Sheet-Tags-Dynamically-Based-on-Relation-Changes/Summary.md>)
  - [Was this page helpful?](<./Managing-Fact-Sheet-Tags-Dynamically-Based-on-Relation-Changes/Was-this-page-helpful.md>)
